/* $Id: dummy_video.cpp 12009 2006-06-10 18:59:00Z torangan $ */
/*
   Copyright (C) 2004 by Philippe Plantier <ayin@anathas.org>
   Part of the Battle for Wesnoth Project http://www.wesnoth.org

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License.
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY.

   See the COPYING file for more details.
*/

#include "../video.hpp"

surface CVideo::getSurface()
{
	return NULL;
}

void update_rect(const SDL_Rect&)
{
}

surface display_format_alpha(surface)
{
	return NULL;
}

surface get_video_surface()
{
	return NULL;
}

